artTitle

# XMLRésuméLibrary: User Guide

annotation | Element Reference | author

## Name

artTitle — A title of an article or other work

## Synopsis

### Content Model

    (#PCDATA|link)*

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `artTitle` element marks the title of a sub-work (such as an article or poem) in a book, journal, magazine, newspaper, anthology, or other compilation.

### Parents

`artTitle` may be contained in these elements: `pub`

## See Also

`bookTitle`.

## Examples

    <pub>
      <artTitle>Lion Brainwashing During the Late 20th Century</artTitle>
      <bookTitle>Journal of the American Feline Psychiatric Association</bookTitle>
    </pub>

    <pub>
      <artTitle>Cucumber Pickling Process Management</artTitle>
      <bookTitle>Proceedings of the European Brine Process Engineers' Group</bookTitle>
    </pub>

annotation | Element Reference | author